@@ -2,9 +2,9 @@ package Test2::Plugin::IOEvents::STDERR;
 use strict;
 use warnings;
 
-our $VERSION = '0.000003';
+our $VERSION = '0.000004';
 
-use parent 'Test2::Plugin::IOEvents::Base';
+BEGIN { require Test2::Plugin::IOEvents::Base; our @ISA = ('Test2::Plugin::IOEvents::Base') };
 
 sub stream_name { 'STDERR' }
 sub diagnostics { 1 }
